==> amfora_1.9.2.orig.tar.gz: amfora-1.9.2/contrib/themes/README.md <==
# User Contributed Themes

You can use these themes by replacing the `[theme]` section of your [config](https://github.com/makeworld-the-better-one/amfora/wiki/Configuration) with their contents. Some themes won't display properly on terminals that do not have truecolor support.

## Amfora

This is the original Amfora theme we all know and love. From v1.9.0 and onwards, the user's terminal theme is used by default. Use this theme to restore the original Amfora look.

<a href="https://raw.githubusercontent.com/makeworld-the-better-one/amfora/master/demo-large.gif">
<img src="../../demo-large.gif" alt="Demo GIF" width="80%">
</a>

## Nord

Contributed by **[@lokesh-krishna](https://github.com/lokesh-krishna)**.

![screenshot of the nord theme](https://user-images.githubusercontent.com/20235646/102846450-005dc480-4436-11eb-89a9-a1a4350f5415.png)

## Dracula

Contributed by **[@crdpa](https://github.com/crdpa)**.

![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983229-5b928d80-2d8a-11eb-8e5c-e5681bb274c5.png)

<details>
<summary>More screenshots</summary>

![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983237-5e8d7e00-2d8a-11eb-8e22-3a3459ae560a.png)
![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983210-53d2e900-2d8a-11eb-9ab7-12dc10c2933a.png)
</details>

## Dracula variant

Contributed by **[@marcransome](https://github.com/marcransome)**.

![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952433-563501ef-4d98-4d43-988e-f15bab7cb155.png)

<details>
<summary>More screenshots</summary>

![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952340-96840ad8-fb78-499d-bf6b-3fcdf659edc7.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952347-6b93d985-afc8-47b4-9569-1775ce4f37e7.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952348-ffcbcc7a-f9ad-41c6-a7d2-5c870754c4c9.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952352-50ca16f3-d255-4a1d-a25b-ccf53116957d.png)

</details>

## Greyscale Light

Contributed by **[@leifmetcalf](https://github.com/leifmetcalf)**.
![screenshot of greyscale light theme](https://user-images.githubusercontent.com/35786377/109232516-53d10200-782d-11eb-9863-4bb745d27195.png)

<details>
<summary>More screenshots</summary>

![screenshot of greyscale light theme](https://user-images.githubusercontent.com/35786377/109232522-55022f00-782d-11eb-93a2-4d50c61317c5.png)
</details>

## Gruvbox

Contributed by **[@Skraylet](https://github.com/Skraylet)**.

![screenshot of gruvbox theme](https://user-images.githubusercontent.com/26380693/100381730-4768bd80-3022-11eb-83ae-bcd0495f2ae9.png)

<details>
<summary>Another screenshot</summary>

![screenshot of gruvbox theme](https://user-images.githubusercontent.com/26380693/100381734-4a63ae00-3022-11eb-9531-a635df310052.png)
</details>

## Solarized

Contributed by **[@bnthor](https://github.com/bnthor)**.

### Dark

![screenshot of solarized dark theme](https://user-images.githubusercontent.com/798657/100597218-77071680-32fd-11eb-8e0d-593ff95b7129.png)

<details>
<summary>Another screenshot</summary>

![screenshot of solarized dark theme](https://user-images.githubusercontent.com/798657/100597236-7b333400-32fd-11eb-8844-b92601da52c7.png)
</details>

### Light

![screenshot of solarized light theme](https://user-images.githubusercontent.com/798657/100597327-9aca5c80-32fd-11eb-8c91-fe3e324d8959.png)

<details>
<summary>Another screenshot</summary>

![screenshot of solarized light theme](https://user-images.githubusercontent.com/798657/100597349-a453c480-32fd-11eb-866e-10b0587228f6.png)
</details>


## One Dark

Contributed by **[@sergetymo](https://github.com/sergetymo)**.

![screenshot of one dark theme](https://user-images.githubusercontent.com/65758149/101183151-c8920700-3657-11eb-87f5-7d1d6ae616f2.png)

<details>
<summary>More screenshots</summary>

![screenshot of bookmark modal](https://user-images.githubusercontent.com/65758149/101183267-f8410f00-3657-11eb-97fa-10f88a9d8de4.png)
![screenshot of error modal](https://user-images.githubusercontent.com/65758149/101183206-da73aa00-3657-11eb-8733-5040c8aefb99.png)
</details>

## Atelier Forest

Contributed by **[@joyalicegu](https://github.com/joyalicegu)**.

### Dark

![screenshot of atelier forest dark theme](https://user-images.githubusercontent.com/16532904/114287117-35a81580-9a19-11eb-8515-a4fa5fee00b8.png)

### Light

![screenshot of atelier forest light theme](https://user-images.githubusercontent.com/16532904/114287105-22954580-9a19-11eb-8c09-2bce083286b2.png)


## Slimey

Contributed by **[@lee2sman](https://github.com/lee2sman)**.

![screenshot of Slimey theme](https://user-images.githubusercontent.com/7377908/114319350-212e5080-9adf-11eb-9d41-d4e800c6570f.png)

## Gruvbox Dark

Contributed by **[@thumb](https://github.com/thumbfighter)**.

![screenshot of Gruvbox Dark theme](https://user-images.githubusercontent.com/19327775/114431954-b97f1080-9b85-11eb-9da5-e1ebf06beba9.png)

<details>
<summary>More screenshots</summary>
  
![screenshot of makeworld.space home page](https://user-images.githubusercontent.com/19327775/114432099-f0552680-9b85-11eb-9b4f-629d62d971b4.png)
![screenshot of error](https://user-images.githubusercontent.com/19327775/114432066-e4696480-9b85-11eb-8ed0-c454f37fe9cf.png)
![screenshot of add bookmark](https://user-images.githubusercontent.com/19327775/114432084-e8958200-9b85-11eb-9813-9982c3c0effa.png)
</details>

## Iceberg Dark

Contributed by **[@knix3](https://github.com/knix3)**

![screenshot of Iceberg Dark theme](https://user-images.githubusercontent.com/69134168/118542790-7b938000-b721-11eb-81e1-ae45cdfbe546.png)
<details>
<summary>More screenshots</summary>

![screenshot of add bookmark](https://user-images.githubusercontent.com/69134168/118543243-07a5a780-b722-11eb-848a-95aa1de30044.png)
![screenshot of error](https://user-images.githubusercontent.com/69134168/118543250-096f6b00-b722-11eb-9dca-d2b1bd6a8885.png)
</details>

## Tokyo Night

Contributed by **[@luetage](https://github.com/luetage)**

![screenshot of Tokyo Night theme](https://user-images.githubusercontent.com/13988217/130348393-69986b51-ddd7-4310-90ae-382461502535.png)

## Yours?

Contribute your own theme by opening a PR.

==> amfora_1.10.0.orig.tar.gz: amfora-1.10.0/contrib/themes/README.md <==
# User Contributed Themes

You can use these themes by replacing the `[theme]` section of your [config](https://github.com/makeworld-the-better-one/amfora/wiki/Configuration) with their contents. Some themes won't display properly on terminals that do not have truecolor support.

## Amfora

This is the original Amfora theme we all know and love. From v1.9.0 and onwards, the user's terminal theme is used by default. Use this theme to restore the original Amfora look.

<a href="https://raw.githubusercontent.com/makeworld-the-better-one/amfora/master/demo-large.gif">
<img src="../../demo-large.gif" alt="Demo GIF" width="80%">
</a>

## Nord

Contributed by **[@lokesh-krishna](https://github.com/lokesh-krishna)**.

![screenshot of the nord theme](https://user-images.githubusercontent.com/20235646/102846450-005dc480-4436-11eb-89a9-a1a4350f5415.png)

## Dracula

Contributed by **[@crdpa](https://github.com/crdpa)**.

![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983229-5b928d80-2d8a-11eb-8e5c-e5681bb274c5.png)

<details>
<summary>More screenshots</summary>

![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983237-5e8d7e00-2d8a-11eb-8e22-3a3459ae560a.png)
![screenshot of dracula theme](https://user-images.githubusercontent.com/61637474/99983210-53d2e900-2d8a-11eb-9ab7-12dc10c2933a.png)
</details>

## Dracula variant

Contributed by **[@marcransome](https://github.com/marcransome)**.

![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952433-563501ef-4d98-4d43-988e-f15bab7cb155.png)

<details>
<summary>More screenshots</summary>

![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952340-96840ad8-fb78-499d-bf6b-3fcdf659edc7.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952347-6b93d985-afc8-47b4-9569-1775ce4f37e7.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952348-ffcbcc7a-f9ad-41c6-a7d2-5c870754c4c9.png)
![screenshot of dracula variant theme](https://user-images.githubusercontent.com/679401/132952352-50ca16f3-d255-4a1d-a25b-ccf53116957d.png)

</details>

## Greyscale Light

Contributed by **[@leifmetcalf](https://github.com/leifmetcalf)**.
![screenshot of greyscale light theme](https://user-images.githubusercontent.com/35786377/109232516-53d10200-782d-11eb-9863-4bb745d27195.png)

<details>
<summary>More screenshots</summary>

![screenshot of greyscale light theme](https://user-images.githubusercontent.com/35786377/109232522-55022f00-782d-11eb-93a2-4d50c61317c5.png)
</details>

## Gruvbox

Contributed by **[@Skraylet](https://github.com/Skraylet)**.

![screenshot of gruvbox theme](https://user-images.githubusercontent.com/26380693/100381730-4768bd80-3022-11eb-83ae-bcd0495f2ae9.png)

<details>
<summary>Another screenshot</summary>

![screenshot of gruvbox theme](https://user-images.githubusercontent.com/26380693/100381734-4a63ae00-3022-11eb-9531-a635df310052.png)
</details>

## Solarized

Contributed by **[@bnthor](https://github.com/bnthor)**.

### Dark

![screenshot of solarized dark theme](https://user-images.githubusercontent.com/798657/100597218-77071680-32fd-11eb-8e0d-593ff95b7129.png)

<details>
<summary>Another screenshot</summary>

![screenshot of solarized dark theme](https://user-images.githubusercontent.com/798657/100597236-7b333400-32fd-11eb-8844-b92601da52c7.png)
</details>

### Light

![screenshot of solarized light theme](https://user-images.githubusercontent.com/798657/100597327-9aca5c80-32fd-11eb-8c91-fe3e324d8959.png)

<details>
<summary>Another screenshot</summary>

![screenshot of solarized light theme](https://user-images.githubusercontent.com/798657/100597349-a453c480-32fd-11eb-866e-10b0587228f6.png)
</details>


## One Dark

Contributed by **[@sergetymo](https://github.com/sergetymo)**.

![screenshot of one dark theme](https://user-images.githubusercontent.com/65758149/101183151-c8920700-3657-11eb-87f5-7d1d6ae616f2.png)

<details>
<summary>More screenshots</summary>

![screenshot of bookmark modal](https://user-images.githubusercontent.com/65758149/101183267-f8410f00-3657-11eb-97fa-10f88a9d8de4.png)
![screenshot of error modal](https://user-images.githubusercontent.com/65758149/101183206-da73aa00-3657-11eb-8733-5040c8aefb99.png)
</details>

## Ayu Light
Contributed by **[@sergetymo](https://github.com/sergetymo)**.

![screenshot of Ayu Light theme](https://user-images.githubusercontent.com/65758149/181745417-48a92840-10d2-4659-950d-fbc9b3588d5c.png)

<details>
<summary>More screenshots</summary>

![screenshot of bookmark modal](https://user-images.githubusercontent.com/65758149/181745413-b5a15120-2ff6-4879-8539-0f02f0eece21.png)
![screenshot of error modal](https://user-images.githubusercontent.com/65758149/181745400-c3e9ba95-aee4-4956-91a8-3dddcbad48cc.png)
</details>


## Atelier Forest

Contributed by **[@joyalicegu](https://github.com/joyalicegu)**.

### Dark

![screenshot of atelier forest dark theme](https://user-images.githubusercontent.com/16532904/114287117-35a81580-9a19-11eb-8515-a4fa5fee00b8.png)

### Light

![screenshot of atelier forest light theme](https://user-images.githubusercontent.com/16532904/114287105-22954580-9a19-11eb-8c09-2bce083286b2.png)


## Slimey

Contributed by **[@lee2sman](https://github.com/lee2sman)**.

![screenshot of Slimey theme](https://user-images.githubusercontent.com/7377908/114319350-212e5080-9adf-11eb-9d41-d4e800c6570f.png)

## Gruvbox Dark

Contributed by **[@thumb](https://github.com/thumbfighter)**.

![screenshot of Gruvbox Dark theme](https://user-images.githubusercontent.com/19327775/114431954-b97f1080-9b85-11eb-9da5-e1ebf06beba9.png)

<details>
<summary>More screenshots</summary>
  
![screenshot of makeworld.space home page](https://user-images.githubusercontent.com/19327775/114432099-f0552680-9b85-11eb-9b4f-629d62d971b4.png)
![screenshot of error](https://user-images.githubusercontent.com/19327775/114432066-e4696480-9b85-11eb-8ed0-c454f37fe9cf.png)
![screenshot of add bookmark](https://user-images.githubusercontent.com/19327775/114432084-e8958200-9b85-11eb-9813-9982c3c0effa.png)
</details>

## Iceberg Dark

Contributed by **[@knix3](https://github.com/knix3)**

![screenshot of Iceberg Dark theme](https://user-images.githubusercontent.com/69134168/118542790-7b938000-b721-11eb-81e1-ae45cdfbe546.png)
<details>
<summary>More screenshots</summary>

![screenshot of add bookmark](https://user-images.githubusercontent.com/69134168/118543243-07a5a780-b722-11eb-848a-95aa1de30044.png)
![screenshot of error](https://user-images.githubusercontent.com/69134168/118543250-096f6b00-b722-11eb-9dca-d2b1bd6a8885.png)
</details>

## Tokyo Night

Contributed by **[@luetage](https://github.com/luetage)**

![screenshot of Tokyo Night theme](https://user-images.githubusercontent.com/13988217/130348393-69986b51-ddd7-4310-90ae-382461502535.png)

## Rosé Pine

Contributed by **[@mvllow](https://github.com/mvllow)**.

### Rosé Pine

<img width="702" alt="screenshot of Rosé Pine theme" src="https://user-images.githubusercontent.com/47515065/157946507-c672e775-e1f1-429a-87a3-0ce947365977.png">

### Rosé Pine Moon

<img width="702" alt="screenshot of Rosé Pine Moon theme" src="https://user-images.githubusercontent.com/47515065/157946274-f4527098-4101-4825-9cc5-563cf541c7ba.png">

### Rosé Pine Dawn

<img width="702" alt="screenshot of Rosé Pine Dawn theme" src="https://user-images.githubusercontent.com/47515065/157946746-7de92443-1a1b-4758-aa6e-717d7b26ebdf.png">

## Yours?

Contribute your own theme by opening a PR.
